/********************************************************************************
** Form generated from reading UI file 'recurrenceactionsscopewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RECURRENCEACTIONSSCOPEWIDGET_H
#define UI_RECURRENCEACTIONSSCOPEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RecurrenceActionsScopeWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    QLabel *iconLabel;
    QSpacerItem *verticalSpacer;
    QLabel *messageLabel;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout;
    QCheckBox *checkBoxPast;
    QCheckBox *checkBoxSelected;
    QCheckBox *checkBoxFuture;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *RecurrenceActionsScopeWidget)
    {
        if (RecurrenceActionsScopeWidget->objectName().isEmpty())
            RecurrenceActionsScopeWidget->setObjectName("RecurrenceActionsScopeWidget");
        RecurrenceActionsScopeWidget->resize(359, 174);
        verticalLayout_2 = new QVBoxLayout(RecurrenceActionsScopeWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        iconLabel = new QLabel(RecurrenceActionsScopeWidget);
        iconLabel->setObjectName("iconLabel");

        gridLayout->addWidget(iconLabel, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);

        messageLabel = new QLabel(RecurrenceActionsScopeWidget);
        messageLabel->setObjectName("messageLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(messageLabel->sizePolicy().hasHeightForWidth());
        messageLabel->setSizePolicy(sizePolicy);
        messageLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        messageLabel->setWordWrap(true);

        gridLayout->addWidget(messageLabel, 0, 1, 2, 1);


        verticalLayout_2->addLayout(gridLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        checkBoxPast = new QCheckBox(RecurrenceActionsScopeWidget);
        checkBoxPast->setObjectName("checkBoxPast");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(checkBoxPast->sizePolicy().hasHeightForWidth());
        checkBoxPast->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(checkBoxPast);

        checkBoxSelected = new QCheckBox(RecurrenceActionsScopeWidget);
        checkBoxSelected->setObjectName("checkBoxSelected");
        sizePolicy1.setHeightForWidth(checkBoxSelected->sizePolicy().hasHeightForWidth());
        checkBoxSelected->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(checkBoxSelected);

        checkBoxFuture = new QCheckBox(RecurrenceActionsScopeWidget);
        checkBoxFuture->setObjectName("checkBoxFuture");
        sizePolicy1.setHeightForWidth(checkBoxFuture->sizePolicy().hasHeightForWidth());
        checkBoxFuture->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(checkBoxFuture);


        horizontalLayout->addLayout(verticalLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);


        retranslateUi(RecurrenceActionsScopeWidget);

        QMetaObject::connectSlotsByName(RecurrenceActionsScopeWidget);
    } // setupUi

    void retranslateUi(QWidget *RecurrenceActionsScopeWidget)
    {
        iconLabel->setText(QString());
        messageLabel->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxPast->setToolTip(tr2i18n("Select calendar items before the specified date", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxPast->setWhatsThis(tr2i18n("Check this box if you want to select calendar items that occur before the specified date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxPast->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxSelected->setToolTip(tr2i18n("Choose the currently selected calendar item", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxSelected->setWhatsThis(tr2i18n("Check this box if you want to select calendar items that occur on the specified date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxSelected->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxFuture->setToolTip(tr2i18n("Select calendar items after the specified date", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxFuture->setWhatsThis(tr2i18n("Check this box if you want to select calendar items that occur after the specified date.", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxFuture->setText(QString());
        (void)RecurrenceActionsScopeWidget;
    } // retranslateUi

};

namespace Ui {
    class RecurrenceActionsScopeWidget: public Ui_RecurrenceActionsScopeWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RECURRENCEACTIONSSCOPEWIDGET_H

